@@ -1,24 +1,25 @@
 package MyScript;
 
-use Command::Do;
+use Command::Do 'fld', 'mth';
 
 fld 'name' => {
-    
+
     required => 1,
     alias    => 'n',
-    optspec  => 's'
-    
+    optspec  => 's',
+    filters  => [qw/trim strip titlecase/]
+
 };
 
 mth 'makeit' => {
     input => ['name'],
     using => sub {
-        
+
         my ($self) = @_;
-        
-        die "You made it!!!!!!!!!!!!!!!!!" ;
-        
-    }
+
+        exit print "You made it ", $self->name, " !!!!!!!!!!!!!!!!!\n";
+
+      }
 };
 
-1;
\ No newline at end of file
+1;
